@@ -105,7 +105,7 @@ test_that(
           data = mtcars,
           x = am,
           y = cyl,
-          perc.k = 2L,
+          digits.perc = 2L,
           title = "mtcars dataset",
           package = "wesanderson",
           palette = "Royal2",
@@ -186,7 +186,7 @@ test_that(
       data = ggplot2::msleep,
       x = conservation,
       y = vore,
-      k = 4L
+      digits = 4L
     ) %>%
       extract_subtitle()
 
@@ -195,7 +195,7 @@ test_that(
       data = ggplot2::msleep,
       x = conservation,
       y = vore,
-      k = 4L
+      digits = 4L
     ))$expression[[1L]]
 
     expect_identical(p_sub, stats_output)
